import { ChangeDetectorRef, OnInit, TemplateRef } from '@angular/core';
import { SkyProgressIndicatorItemStatus } from '../types/progress-indicator-item-status';
import * as i0 from "@angular/core";
/**
 * Specifies a step to include in the progress indicator. Each step requires a label,
 * and you can also specify step details within the `sky-progress-indicator-item` element.
 */
export declare class SkyProgressIndicatorItemComponent implements OnInit {
    #private;
    /**
     * The step label for the step in the progress indicator.
     * @required
     */
    set title(value: string | undefined);
    get title(): string | undefined;
    /**
     * A help key that identifies the global help content to display. When specified along with `title`, a [help inline](https://developer.blackbaud.com/skyux/components/help-inline) button is
     * placed beside the progress indicator item label. Clicking the button invokes global help as configured by the application.
     * This property only applies when `title` is also specified.
     */
    helpKey: string | undefined;
    /**
     * The content of the help popover. When specified along with `title`, a [help inline](https://developer.blackbaud.com/skyux/components/help-inline)
     * button is added to the progress indicator item label. The help inline button displays a [popover](https://developer.blackbaud.com/skyux/components/popover)
     * when clicked using the specified content and optional title. This property only applies when `title` is also specified.
     */
    helpPopoverContent: string | TemplateRef<unknown> | undefined;
    /**
     * The title of the help popover. This property only applies when `helpPopoverContent` is
     * also specified.
     */
    helpPopoverTitle: string | undefined;
    set status(value: SkyProgressIndicatorItemStatus | undefined);
    get status(): SkyProgressIndicatorItemStatus;
    formattedTitle: string | undefined;
    set isVisible(value: boolean | undefined);
    get isVisible(): boolean;
    set showStatusMarker(value: boolean | undefined);
    get showStatusMarker(): boolean;
    set showTitle(value: boolean | undefined);
    get showTitle(): boolean;
    statusName: string;
    constructor(changeDetector: ChangeDetectorRef);
    ngOnInit(): void;
    showStepNumber(step: number): void;
    hideStepNumber(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<SkyProgressIndicatorItemComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<SkyProgressIndicatorItemComponent, "sky-progress-indicator-item", never, { "title": { "alias": "title"; "required": false; }; "helpKey": { "alias": "helpKey"; "required": false; }; "helpPopoverContent": { "alias": "helpPopoverContent"; "required": false; }; "helpPopoverTitle": { "alias": "helpPopoverTitle"; "required": false; }; }, {}, never, [".sky-control-help", "*"], false, never>;
}
