import { AfterContentInit, ChangeDetectorRef, EventEmitter, OnDestroy, OnInit, QueryList } from '@angular/core';
import { SkyAppWindowRef, SkyLogService } from '@skyux/core';
import { Subject } from 'rxjs';
import { SkyProgressIndicatorItemComponent } from './progress-indicator-item/progress-indicator-item.component';
import { SkyProgressIndicatorChange } from './types/progress-indicator-change';
import { SkyProgressIndicatorDisplayModeType } from './types/progress-indicator-display-mode-type';
import { SkyProgressIndicatorItemStatus } from './types/progress-indicator-item-status';
import { SkyProgressIndicatorMessage } from './types/progress-indicator-message';
import { SkyProgressIndicatorMessageType } from './types/progress-indicator-message-type';
import * as i0 from "@angular/core";
export declare class SkyProgressIndicatorComponent implements OnInit, AfterContentInit, OnDestroy {
    #private;
    /**
     * The orientation of the progress indicator, which can be vertical or horizontal.
     * For [passive progress indicators](https://developer.blackbaud.com/skyux-progress-indicator/docs/passive-indicator)
     * and [waterfall progress indicators](https://developer.blackbaud.com/skyux/components/progress-indicator/waterfall-progress-indicator),
     * use the vertical display mode. For [modal wizards](https://developer.blackbaud.com/skyux/components/wizard),
     * use the horizontal display mode.
     * @deprecated The property was designed to create wizards by setting `displayMode="horizontal"` on progress indicators in modals,
     * but this wizard implementation was replaced by the
     * [Wizard (Tabs) component](https://developer.blackbaud.com/skyux/components/progress-indicator).
     * @default "vertical"
     */
    set displayMode(value: SkyProgressIndicatorDisplayModeType | undefined);
    get displayMode(): SkyProgressIndicatorDisplayModeType;
    /**
     * Whether the progress indicator is passive. Passive progress indicators inform users of
     * progress that concerns them but that they are not responsible for, and they must use the vertical display mode.
     * @default false
     */
    set isPassive(value: boolean | undefined);
    get isPassive(): boolean | undefined;
    /**
     * The observable of `SkyProgressIndicatorMessage` that determines the status to
     * display for items in the progress indicator. The message stream is a queue of
     * commanding messages to change the state of the progress indicator based on the message type.
     */
    set messageStream(value: Subject<SkyProgressIndicatorMessage | SkyProgressIndicatorMessageType> | undefined);
    /**
     * The index for the item to make active when the progress indicator
     * loads. All steps that precede the active item are marked as complete, and all steps
     * that follow the active item are marked as incomplete.
     */
    set startingIndex(value: number | undefined);
    get startingIndex(): number;
    /**
     * Fires when the progress indicator changes the status of an item.
     */
    progressChanges: EventEmitter<SkyProgressIndicatorChange>;
    get hasFinishButton(): boolean | undefined;
    set hasFinishButton(value: boolean | undefined);
    itemComponents: QueryList<SkyProgressIndicatorItemComponent> | undefined;
    cssClassNames: string[];
    itemStatuses: SkyProgressIndicatorItemStatus[];
    constructor(changeDetector: ChangeDetectorRef, windowRef: SkyAppWindowRef, logger: SkyLogService);
    ngOnInit(): void;
    ngAfterContentInit(): void;
    ngOnDestroy(): void;
    sendMessage(message: SkyProgressIndicatorMessage): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<SkyProgressIndicatorComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<SkyProgressIndicatorComponent, "sky-progress-indicator", never, { "displayMode": { "alias": "displayMode"; "required": false; }; "isPassive": { "alias": "isPassive"; "required": false; }; "messageStream": { "alias": "messageStream"; "required": false; }; "startingIndex": { "alias": "startingIndex"; "required": false; }; }, { "progressChanges": "progressChanges"; }, ["itemComponents"], ["*"], false, never>;
}
